@@ -40,6 +40,8 @@ using namespace DialogDsl::operators;
 #include "noticewidget.h"
 #include "namechooserwidget.h"
 #include "passwordchooserwidget.h"
+#include "offlineonlywidget.h"
+#include "vaultdeletionwidget.h"
 
 using PlasmaVault::Vault;
 
@@ -53,6 +55,7 @@ public:
 
     steps currentSteps;
     QVector<DialogDsl::DialogModule*> currentModuleDialogs;
+    QSet<DialogDsl::DialogModule*> invalidModules;
 
     steps defaultSteps
     {
@@ -61,20 +64,14 @@ public:
             directoryChooser(DirectoryChooserWidget::RequireEmptyMountPoint)
         },
 
-        i18n("Activities") / step {
-            activitiesChooser()
-        }
+        i18n("Advanced") / step {
+            activitiesChooser(),
+            offlineOnlyChooser()
+        },
 
-        /*
-        i18n("Dismantle") / step {
-            notice(
-               "dismantle-message",
-               i18n("Note that Plasma Vault will not delete any of the files,\n\
-                     the dismantling process only removes the vault from Plasma.\n\
-                     You will need to remove the files manually."),
-               NoticeWidget::ShowAlways)
+        i18n("Delete") / step {
+            vaultDeletion()
         }
-        */
     };
 
     Logic logic
@@ -106,9 +103,11 @@ public:
         auto modules = logic[Key(vault->backend().toLatin1())];
 
         Vault::Payload payload {
+            { KEY_DEVICE,      QVariant(vault->device()) },
             { KEY_NAME,        QVariant(vault->name()) },
             { KEY_MOUNT_POINT, QVariant(vault->mountPoint()) },
-            { KEY_ACTIVITIES,  QVariant(vault->activities()) }
+            { KEY_ACTIVITIES,  QVariant(vault->activities()) },
+            { KEY_OFFLINEONLY, QVariant(vault->isOfflineOnly()) }
         };
 
         for (const auto& module: modules) {
@@ -116,6 +115,24 @@ public:
             stepWidget->init(payload);
             tabs->addTab(stepWidget, module.title());
             currentModuleDialogs << stepWidget;
+
+            QObject::connect(
+                stepWidget, &DialogModule::isValidChanged,
+                q, [this,stepWidget] (bool valid) {
+                    if (valid) {
+                        invalidModules.remove(stepWidget);
+                    } else {
+                        invalidModules << stepWidget;
+                    }
+
+                    ui.buttons->button(QDialogButtonBox::Ok)->setEnabled(invalidModules.isEmpty());
+                });
+
+            QObject::connect(
+                stepWidget, &DialogModule::requestCancellation,
+                q, [this] {
+                    q->reject();
+                });
         }
     }
 
@@ -139,12 +156,14 @@ public:
         const auto name = collectedPayload[KEY_NAME].toString();
         const PlasmaVault::MountPoint mountPoint(collectedPayload[KEY_MOUNT_POINT].toString());
         const auto activities = collectedPayload[KEY_ACTIVITIES].toStringList();
+        const auto isOfflineOnly = collectedPayload[KEY_OFFLINEONLY].toBool();
 
         if (name.isEmpty() || mountPoint.isEmpty()) return;
 
         vault->setName(name);
         vault->setMountPoint(mountPoint);
         vault->setActivities(activities);
+        vault->setIsOfflineOnly(isOfflineOnly);
     }
 };
 
