@@ -34,7 +34,7 @@ class VaultApplet: public Plasma::Applet
     Q_PROPERTY(QObject* vaultsModel READ vaultsModel CONSTANT)
 
 public:
-    VaultApplet(QObject *parent, const QVariantList &args);
+    explicit VaultApplet(QObject *parent, const QVariantList &args);
     ~VaultApplet();
 
     QObject *vaultsModel();
